package muyu.data.test.clinet.config;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.edition.constant.RuleOperationConstants;
import com.muyu.edition.domain.Config;
import com.muyu.edition.domain.Edition;
import com.muyu.edition.domain.RuleEngine;
import com.muyu.goods.edition.remote.EditionDataRemoteService;
import com.muyu.goods.edition.remote.RemoteDataManagerService;
import lombok.extern.log4j.Log4j2;
import muyu.data.test.clinet.config.runner.DataEditionConfigRunner;
import muyu.data.test.common.context.DataModelContextHolder;
import muyu.data.test.common.context.DataSetContextHolder;
import muyu.data.test.common.dataSoutce.EditionSoutceConfig;
import muyu.data.test.common.dymamicLoad.DynamicLoader;
import muyu.data.test.common.model.DataModel;
import muyu.data.test.common.model.DataSetModel;
import muyu.data.test.common.model.RecordModel;
import muyu.data.test.common.model.process.DataModelProcessModel;
import muyu.data.test.common.model.process.DataSetProcessModel;
import muyu.data.test.common.model.process.RecordProcessModel;
import muyu.data.test.common.req.TestDataModelReq;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Import;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Log4j2
@ComponentScan
@Import(value = DataEditionConfigRunner.class)
public class DataEditionConfig {
    @Autowired
    private EditionDataRemoteService editionDataRemoteService;
    public Object setColumn(TestDataModelReq testDataModelReq) {
        switch (testDataModelReq.getRuleLevel()){
            case 2:
                //先获取一个记录列
                List<RecordModel> dataModels = new ArrayList<>();
                // 获取数据集的数据
                List<List<DataModel>> dataModelLists = testDataModelReq.getDataModelLists();
                //给记录列赋值
                dataModelLists.stream().forEach(res -> {
                    //获取记录模型
                    RecordModel recordModel = RecordModel.builder().dataModels(res).build();
                    dataModels.add(recordModel);
                });
                //调取数据集的处理模型
                DataSetModel dataSetModel = DataSetModel.builder().recordModels(dataModels).build();
                //调取数据集的上下文
                DataSetProcessModel dataSetProcessModel = new DataSetProcessModel();
                dataSetProcessModel.setDataSetModel(dataSetModel);
                DataSetContextHolder.set(dataSetProcessModel);
            case 3:
                //调取记录的处理模型
                RecordModel recordModel = RecordModel.builder()
                        .dataModels(testDataModelReq.getDataModelList())
                        .build();
                //调取记录的上下文
                RecordProcessModel recordProcessModel = new RecordProcessModel();
                recordProcessModel.setKeys(testDataModelReq.getKeys());
                recordProcessModel.setRecordModel(recordModel);
            case 4:
                //调取数据处理模型
                DataModelProcessModel dataModelProcessModel = new DataModelProcessModel();
                dataModelProcessModel.setDataModel(testDataModelReq.getDataModel());
                //调取数据明显上下文
                DataModelContextHolder.set(dataModelProcessModel);
        }
        // 获取规则
        List<Edition> listEdition = editionDataRemoteService.lists().getData();
        List<Edition> editions = listEdition.stream().filter(e -> e.getId().equals(testDataModelReq.getEditionId())).collect(Collectors.toList());
        Edition edition = editions.get(0);
        Map<String, byte[]> aByte = EditionSoutceConfig.getByte(edition.getId());

        try {
            // 加载class文件到虚拟机中，然后通过反射执行
            @SuppressWarnings("resource")
            DynamicLoader.MemoryClassLoader classLoader = new DynamicLoader.MemoryClassLoader(aByte);
            Class<?> clazz = classLoader.loadClass(edition.getVersionClass());

            // 调用ruleTest方法
            Method mainMethod = clazz.getDeclaredMethod("execution");
            Object o = clazz.newInstance();
            mainMethod.invoke(o);
        } catch (Exception e) {
            e.printStackTrace();
            throw new ServiceException("异常"+e.getMessage());
        }
        return "正常，无需返回";
    }

    public void editionInitialize() {
        //获取规则
        Result<List<Edition>> tableDataInfoResult = editionDataRemoteService.lists();
        List<Edition> editions = tableDataInfoResult.getData();
        EditionSoutceConfig.indexByte(editions);
    }
}
