package com.muyu.edition.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.edition.domain.Edition;
import com.muyu.edition.mapper.EditionMapper;
import com.muyu.edition.mq.Producer;
import com.muyu.edition.service.IEditionService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.kafka.KafkaProperties;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

import static java.util.concurrent.Executors.newFixedThreadPool;

/**
 * 规则引擎版本Service业务层处理
 *
 * @author muyu
 * @date 2024-05-06
 */
@Slf4j
@Service
public class EditionServiceImpl extends ServiceImpl<EditionMapper, Edition> implements IEditionService {
    @Autowired
    private EditionMapper editionMapper;
    @Autowired
    private Producer producer;

    /**
     * 查询规则引擎版本
     *
     * @param id 规则引擎版本主键
     * @return 规则引擎版本
     */
    @Override
    public Edition selectEditionById(Long id) {
        return editionMapper.selectEditionById(id);
    }

    @Override
    public List<Edition> lists() {
        return editionMapper.lists();
    }

    /**
     * 获取相应的规则引擎版本
     *
     * @param ruleId
     * @return
     */
    @Override
    public List<Edition> selectListRuleId(Long ruleId) {
        return selectEditionList().stream().filter(c -> c.getRuleId().equals(ruleId)).collect(Collectors.toList());
    }

    /**
     * 查询规则引擎版本列表
     *
     * @return 规则引擎版本
     */
    @Override
    public List<Edition> selectEditionList() {
        return editionMapper.selectEditionList();
    }

    /**
     * 新增规则引擎版本
     *
     * @param edition 规则引擎版本
     * @return 结果
     */
    @Override
    public int insertEdition(Edition edition) {
        int id = editionMapper.insertEdition(edition);
        if (id > 0){
            System.out.println("添加");
            producer.editionMq(id);
        }
        return id;
    }

    /**
     * 修改规则引擎版本
     *
     * @param edition 规则引擎版本
     * @return 结果
     */
    @Override
    public int updateEdition(Edition edition) {
        int id = editionMapper.updateEdition(edition);
        if (id>0){
            //将修改的数据传输到mq
            System.out.println("修改");
            producer.editionMq(id);
        }
        return id;
    }

    /**
     * 批量删除规则引擎版本
     *
     * @param ids 需要删除的规则引擎版本主键
     * @return 结果
     */
    @Override
    public int deleteEditionByIds(Long[] ids) {
        return editionMapper.deleteEditionByIds(ids);
    }

    /**
     * 删除规则引擎版本信息
     *
     * @param id 规则引擎版本主键
     * @return 结果
     */
    @Override
    public int deleteEditionById(Long id) {
        return editionMapper.deleteEditionById(id);
    }

    @Override
    public void updRuleSsTest(Integer id, Integer ruleIsTest) {
         editionMapper.updRuleSsTest(id,ruleIsTest);
    }

    @Override
    public String updRuleStatus(Long id, String ruleStatus) {
        Integer i = editionMapper.updRuleStatus(id, ruleStatus);
        if (i>0){
            return "完成处理";
        }else{
            return "处理失败";
        }
    }

    @Override
    public String updEditionStatus(Long id) {
        Integer i = editionMapper.updEditionStatus(id);
        if (i>0){
            return "成功激活";
        }else{
            return "激活失败";
        }
    }
}
